{*******************************************************************************
                 JH_ComboBox for Delphi 4,5,6,7
 Author:
        Jan HLAVENKA
        e-mail: jan@hlavenka.cz
        web: http://jan.hlavenka.cz

 Copyright  1997-2003 by Jan HLAVENKA

 This software is provided as it is, without any kind of warranty
 given. Use it at your own risk.

 You may use this software in any kind of development, including
 comercial, redistribute, and modify it freely, under the
 following restrictions :

 1. The origin of this software may not be mispresented, you must
    not claim that you wrote the original software. If you use
    this software in any kind of product, it would be appreciated
    that there in a information box, or in the documentation would
    be an acknowledgmnent like this
           Parts Copyright  2003 by Jan HLAVENKA

 2. You may not have any income from distributing this source
    to other developers. When you use this product in a comercial
    package, the source may not be charged seperatly.

 3. This notice should also follow the package if you use this
    source in a commercial product.

*******************************************************************************}

unit JHComboBox;

interface

uses
  SysUtils, Classes, StdCtrls;

type
  TJHComboBox = class(TComboBox)
  private
    FValueList: TStrings;
    FActual: string;
    function  GetValueList: TStrings;
    procedure SetValueList(const Value: TStrings);
    function  GetActualInt: integer;
    function  GetCountNum: integer;
    function  GetActual: string;
  public
    constructor Create(AOwner: TComponent); override;
    destructor  Destroy; override;
    procedure  LoadFromFile(FileName: string);
    procedure  SaveToFile(FileName: string);
    procedure  Sort;
{$IFDEF VER140} //comment this line for Delphi 7
//{$IFDEF VER150} uncomment this line for Delphi 7
//Delphi 6,7
    procedure  Clear; override;
{$ELSE}
//Delphi 4,5
    procedure  Clear;
{$ENDIF}
  published
    property  Actual: string read GetActual;
    property  ActualInt: integer read GetActualInt;
    property  Count: integer read GetCountNum;
    property  ValueList: TStrings read GetValueList write SetValueList;
  end;

procedure Register;

implementation

{ TJHComboBox by Jan HLAVENKA}

constructor TJHComboBox.Create(AOwner: TComponent);
begin
  inherited;
  FValueList:=TStringList.Create;
  FValueList.Clear;
  FActual:='';
end;

destructor TJHComboBox.Destroy;
begin
  FValueList.Free;
  inherited;
end;

function TJHComboBox.GetValueList: TStrings;
begin
    if Assigned(FValueList) then Result:=FValueList
     else Result:=nil;
end;

procedure TJHComboBox.SetValueList(const Value: TStrings);
begin
    if Assigned(FValueList) then FValueList.Assign(Value);
end;

function TJHComboBox.GetActualInt: integer;
begin
   Result:=StrToIntDef(FActual,0)
end;

function TJHComboBox.GetCountNum: integer;
begin
   if ValueList.Count=Items.Count then Result:=Items.Count
    else Result:=ValueList.Count;
end;

procedure TJHComboBox.Sort;
var i: integer;
    list: TStringList;
begin
   list:=TStringList.Create;
   try
    for i:=0 to Items.Count-1 do begin
     if ValueList.Count >= Items.Count then list.Add(Items[i]+';'+ValueList[i])
      else list.Add(Items[i]+';');
    end;
   list.Sorted:=true;
   RecreateWnd;
   Items.Clear;
   ValueList.Clear;
   for i:=0 to list.Count-1 do begin
    Items.Add(copy(list[i],1,Pos(';',list[i])-1));
    ValueList.Add(copy(list[i],Pos(';',list[i])+1,length(list[i])));
   end;
   finally
    list.Free;
   end;
end;

function TJHComboBox.GetActual: string;
begin
  FActual:='';
  if Assigned(FValueList) then begin
    if (FValueList.Count>Self.ItemIndex) AND (Self.ItemIndex<>-1)
      then FActual:=FValueList[Self.ItemIndex];
  end;
  Result:=FActual;
end;

procedure TJHComboBox.LoadFromFile(FileName: string);
var i: integer;
    temp: string;
begin
   if Assigned(FValueList) then begin
    FValueList.Clear;
    Self.Items.LoadFromFile(FileName);
    for i:=0 to Self.Items.Count-1 do begin
     temp:=Self.Items[i];
     FValueList.Add(copy(temp,Pos(';',temp)+1,256));
     delete(temp,Pos(';',temp),256);
     Self.Items[i]:=temp;
    end;
   end;
end;

procedure TJHComboBox.SaveToFile(FileName: string);
var list: TStrings;
    i: integer;
begin
   if Assigned(FValueList) then begin
    list:=TStringList.Create;
    list.Clear;
    for i:=0 to Self.Items.Count-1 do begin
     list.Add(Self.Items[i]+';'+FValueList[i]);
    end;
    list.SaveToFile(FileName);
    list.Free;
   end;
end;

procedure TJHComboBox.Clear;
begin
   Self.Items.Clear;
   Self.ValueList.Clear;
end;

procedure Register;
begin
   RegisterComponents('Jan HLAVENKA', [TJHComboBox]);
end;

end.
